@@ -3,7 +3,7 @@ from plone.app.testing import applyProfile
 from plone.app.testing import PLONE_FIXTURE
 from plone.app.testing import IntegrationTesting
 from plone.app.testing import FunctionalTesting
-
+from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
 from plone.testing import z2
 
 from zope.configuration import xmlconfig
@@ -39,3 +39,7 @@ COLLECTIVE_GOOGLEAUTHENTICATOR_FUNCTIONAL_TESTING = FunctionalTesting(
     bases=(COLLECTIVE_GOOGLEAUTHENTICATOR_FIXTURE, z2.ZSERVER_FIXTURE),
     name="CollectivegoogleauthenticatorLayer:Functional"
 )
+COLLECTIVE_GOOGLEAUTHENTICATOR_ROBOT_TESTING = FunctionalTesting(
+    bases=(COLLECTIVE_GOOGLEAUTHENTICATOR_FIXTURE, REMOTE_LIBRARY_BUNDLE_FIXTURE, z2.ZSERVER_FIXTURE),
+    name="CollectivegoogleauthenticatorLayer:Robot"
+)
